//@line 4 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/he/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/he/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/he/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 12 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/he/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", false);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", true);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "he");

//@line 23 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/he/calendar/lightning-l10n.js"
pref("calendar.categories.names", "יום השנה,יום הולדת,עסקים,שיחות,לקוחות,תחרות,לקוח,מועדפים,מעקב,מתנות,חגים,רעיונות,סוגיות,פגישה,שונות,אישי,פרוייקטים,חגים לאומיים,מצב,ספקים,טיול,חופשה");
